#!/bin/bash -e

echo "================= Adding some global settings ==================="
mkdir -p "$HOME/.ssh/"
mv /c7arm/config "$HOME/.ssh/"
cat /c7arm/90forceyes >> /etc/yum.conf
touch "$HOME/.ssh/known_hosts"
mkdir -p /etc/drydock

echo "================= Installing basic packages ================"

yum update -y
yum -y install  \
curl \
ftp \
gettext \
mercurial \
openssh-client \
openssl \
samba-client \
sudo \
unzip \
wget \
which


echo "================= Installing Python packages ==================="
sudo yum install -y python3-pip
sudo yum install -y gcc libffi-devel python3-devel openssl-devel
python3 -m pip install --upgrade pip
sudo pip3 install virtualenv==20.4.7
sudo pip3 install cryptography==3.3.2
sudo pip3 install -q pyOpenSSL==20.0.1


export JQ_VERSION=1.7
echo "================= Adding JQ $JQ_VERSION ==================="
wget https://github.com/jqlang/jq/releases/download/jq-"$JQ_VERSION"/jq-linux-arm64 -O jq
chmod +x jq
mv jq /usr/local/bin

echo "================= Installing CLIs packages ======================"

export GIT_VERSION=1.8.3.1
echo "================= Installing Git $GIT_VERSION ===================="
sudo yum update
sudo yum install -y git

echo "================= Installing Git lfs ===================="
wget https://github.com/git-lfs/git-lfs/releases/download/v3.4.0/git-lfs-linux-arm64-v3.4.0.tar.gz
tar -xvf git-lfs-linux-arm64-v3.4.0.tar.gz

echo "================= Installing Node16  ===================="
NODEJS_VERSION=v16.16.0
mkdir /node16
pushd /node16
wget https://nodejs.org/dist/$NODEJS_VERSION/node-$NODEJS_VERSION-linux-arm64.tar.xz
tar -xf node-$NODEJS_VERSION-linux-arm64.tar.xz
ln -s /node16/node-$NODEJS_VERSION-linux-arm64/bin/node /usr/local/bin/node16
popd
echo "Node16 version installed: $(node16 -v)"

echo '#!/bin/bash' > /usr/local/bin/node18
echo 'echo "node18 is not available. Trying node16." >&2' >> /usr/local/bin/node18
echo '/usr/local/bin/node16 "$@"' >> /usr/local/bin/node18
chmod +x /usr/local/bin/node18

echo "================= Adding gcloud =================="
tar -xf /c7arm/gcloudsdk.tar.gz
sudo ./google-cloud-sdk/install.sh -q --path-update true

export AWS_VERSION=1.19.103
echo "================= Adding awscli $AWS_VERSION ===================="
sudo pip3 install awscli=="$AWS_VERSION"

echo "================ Adding azure-cli $AZURE_CLI_VERSION  =============="
sudo pip3 install azure-cli

export JFROG_VERSION=1.54.1
echo "================= Adding jfrog-cli $JFROG_VERSION==================="
wget -nv https://releases.jfrog.io/artifactory/jfrog-cli/v1/"$JFROG_VERSION"/jfrog-cli-linux-arm64/jfrog?bt_package=jfrog-cli-linux-arm64 -O jfrog
sudo chmod +x jfrog
sudo mv jfrog /usr/bin/jfrog

KUBECTL_VERSION=1.24.0
echo "================= Adding kubectl "$KUBECTL_VERSION" ==================="
curl -LO https://storage.googleapis.com/kubernetes-release/release/v"$KUBECTL_VERSION"/bin/linux/arm64/kubectl
sudo chmod +x ./kubectl
sudo mv ./kubectl /usr/local/bin/kubectl

TF_VERSION=1.2.0
echo "================ Adding terraform- $TF_VERSION  ===================="
TF_FILE=terraform_"$TF_VERSION"_linux_arm64.zip

echo "Fetching terraform"
echo "-----------------------------------"
rm -rf /tmp/terraform
mkdir -p /tmp/terraform
wget -nv https://releases.hashicorp.com/terraform/$TF_VERSION/$TF_FILE
unzip -o $TF_FILE -d /tmp/terraform
sudo chmod +x /tmp/terraform/terraform
mv /tmp/terraform/terraform /usr/bin/terraform

PK_VERSION=1.8.0
echo "================ Adding packer $PK_VERSION  ===================="
PK_FILE=packer_"$PK_VERSION"_linux_arm64.zip

echo "Fetching packer"
echo "-----------------------------------"
# unlink required to avoid naming collision
unlink /usr/sbin/packer
rm -rf /tmp/packer
mkdir -p /tmp/packer
wget -nv https://releases.hashicorp.com/packer/$PK_VERSION/$PK_FILE
unzip -o $PK_FILE -d /tmp/packer
sudo chmod +x /tmp/packer/packer
mv /tmp/packer/packer /usr/bin/packer

echo "======= Adding docker compose ======="
sudo mv /c7arm/docker-compose /usr/local/bin/docker-compose
sudo chmod +x /usr/local/bin/docker-compose

HELM_VERSION=2.16.9
echo "================= helm 2 cli $HELM_VERSION ======================================"
curl -sSL -o helm.tar.gz https://get.helm.sh/helm-v"$HELM_VERSION"-linux-arm64.tar.gz
tar xzvf helm.tar.gz
chmod +x ./linux-arm64/helm
chmod +x ./linux-arm64/tiller
sudo mv ./linux-arm64/helm /usr/local/bin/helm
sudo mv ./linux-arm64/tiller /usr/local/bin/tiller
rm -fr ./linux-arm64
rm -f helm.tar.gz

HELM_VERSION=3.9.0
echo "================= helm3 cli $HELM_VERSION ======================================"
curl -sSL -o helm.tar.gz https://get.helm.sh/helm-v"$HELM_VERSION"-linux-arm64.tar.gz
tar xzvf helm.tar.gz
chmod +x ./linux-arm64/helm
sudo mv ./linux-arm64/helm /usr/local/bin/helm3
rm -fr ./linux-arm64
rm -f helm.tar.gz

BUILDX_VERSION=0.10.5
echo "======================= buildx version $BUILDX_VERSION"
mkdir -p $HOME/.docker/cli-plugins
wget -O $HOME/.docker/cli-plugins/docker-buildx https://github.com/docker/buildx/releases/download/v"$BUILDX_VERSION"/buildx-v"$BUILDX_VERSION".linux-arm64
chmod +x $HOME/.docker/cli-plugins/docker-buildx
